@@ -33,7 +33,11 @@
 #include <errno.h>
 #include <sys/types.h>
 
+#if defined(_WIN32) && !defined(__MINGW32__)
+#include "config-msvc.h"
+#else
 #include "config.h"
+#endif
 
 #if defined(_WIN32) && !defined(__MINGW32__)
 #include <io.h>
@@ -961,12 +965,12 @@ load_file (sqlite3 * handle, const char *file_path, int gps_only, int metadata)
       }
   stop:
     if (!ok_exif)
-	printf ("file '%s' doesn't seems to be a valid EXIF\n", file_path);
+	printf ("file '%s' doesn't seem to be a valid EXIF file\n", file_path);
     else if (!loaded)
       {
 	  if (gps_skip)
 	      printf
-		  ("file '%s' is a valid EXIF, but doesn't contains any GPS info\n",
+		  ("file '%s' is a valid EXIF file, but doesn't contain any GPS info\n",
 		   file_path);
 	  else
 	      printf ("SQL error(s): file '%s' was not loaded\n", file_path);
@@ -1425,7 +1429,7 @@ spatialite_autocreate (sqlite3 * db)
 	return;
 
 /* all right, it's empty: proceeding to initialize */
-    strcpy (sql, "SELECT InitSpatialMetadata()");
+    strcpy (sql, "SELECT InitSpatialMetadata(1)");
     ret = sqlite3_exec (db, sql, NULL, NULL, &err_msg);
     if (ret != SQLITE_OK)
       {
@@ -1443,16 +1447,16 @@ do_help ()
     fprintf (stderr,
 	     "==============================================================\n");
     fprintf (stderr,
-	     "-h or --help                      print this help message\n");
+	     "-h or --help                    print this help message\n");
     fprintf (stderr,
-	     "-d or --db-path pathname          the SpatiaLite db path\n");
+	     "-d or --db-path    pathname     the SpatiaLite db path\n");
     fprintf (stderr,
-	     "-D or --dir     dir_path          the DIR path containing EXIF files\n");
-    fprintf (stderr, "-f or --file    file_name         a single EXIF file\n");
+	     "-D or --dir        dir_path     the DIR path containing EXIF files\n");
+    fprintf (stderr, "-f or --file-path  file_name    a single EXIF file\n\n");
     fprintf (stderr, "you can specify the following options as well\n");
-    fprintf (stderr, "--any-exif                 *default*\n");
+    fprintf (stderr, "--any-exif         *default*\n");
     fprintf (stderr, "--gps-exif-only\n\n");
-    fprintf (stderr, "--metadata                 *default*\n");
+    fprintf (stderr, "--metadata         *default*\n");
     fprintf (stderr, "--no-metadata\n\n");
 }
 
@@ -1471,6 +1475,7 @@ main (int argc, char *argv[])
     sqlite3 *handle;
     int ret;
     int cnt = 0;
+    void *cache;
     for (i = 1; i < argc; i++)
       {
 	  /* parsing the invocation arguments */
@@ -1589,6 +1594,8 @@ main (int argc, char *argv[])
 	  sqlite3_close (handle);
 	  return -1;
       }
+    cache = spatialite_alloc_connection ();
+    spatialite_init_ex (handle, cache, 0);
     spatialite_autocreate (handle);
     if (!checkExifTables (handle))
       {
@@ -1605,6 +1612,7 @@ main (int argc, char *argv[])
     if (ret != SQLITE_OK)
 	fprintf (stderr, "sqlite3_close() error: %s\n",
 		 sqlite3_errmsg (handle));
+    spatialite_cleanup_ex (cache);
     if (cnt)
 	fprintf (stderr,
 		 "\n\n***   %d EXIF photo%s successfully inserted into the DB\n",
