@@ -37,7 +37,11 @@
 
 #include <expat.h>
 
+#if defined(_WIN32) && !defined(__MINGW32__)
+#include "config-msvc.h"
+#else
 #include "config.h"
+#endif
 
 #ifdef SPATIALITE_AMALGAMATION
 #include <spatialite/sqlite3.h>
@@ -1288,7 +1292,7 @@ spatialite_autocreate (sqlite3 * db)
 	return;
 
 /* all right, it's empty: proceding to initialize */
-    strcpy (sql, "SELECT InitSpatialMetadata()");
+    strcpy (sql, "SELECT InitSpatialMetadata(1)");
     ret = sqlite3_exec (db, sql, NULL, NULL, &err_msg);
     if (ret != SQLITE_OK)
       {
@@ -1299,7 +1303,7 @@ spatialite_autocreate (sqlite3 * db)
 }
 
 static void
-open_db (const char *path, sqlite3 ** handle)
+open_db (const char *path, sqlite3 ** handle, void *cache)
 {
 /* opening the DB */
     sqlite3 *db_handle;
@@ -1317,6 +1321,7 @@ open_db (const char *path, sqlite3 ** handle)
     int coord_dimension = 0;
     int gc_srid = 0;
     int type = 0;
+    int geometry_type = 0;
     int spatial_index_enabled = 0;
     const char *name;
     int i;
@@ -1325,7 +1330,6 @@ open_db (const char *path, sqlite3 ** handle)
     int columns;
 
     *handle = NULL;
-    spatialite_init (0);
     printf ("SQLite version: %s\n", sqlite3_libversion ());
     printf ("SpatiaLite version: %s\n\n", spatialite_version ());
 
@@ -1340,6 +1344,7 @@ open_db (const char *path, sqlite3 ** handle)
 	  db_handle = NULL;
 	  return;
       }
+    spatialite_init_ex (db_handle, cache, 0);
     spatialite_autocreate (db_handle);
 
 /* checking the GEOMETRY_COLUMNS table */
@@ -1364,6 +1369,8 @@ open_db (const char *path, sqlite3 ** handle)
 		    gc_srid = 1;
 		if (strcasecmp (name, "type") == 0)
 		    type = 1;
+		if (strcasecmp (name, "geometry_type") == 0)
+		    geometry_type = 1;
 		if (strcasecmp (name, "spatial_index_enabled") == 0)
 		    spatial_index_enabled = 1;
 	    }
@@ -1372,6 +1379,9 @@ open_db (const char *path, sqlite3 ** handle)
     if (f_table_name && f_geometry_column && type && coord_dimension
 	&& gc_srid && spatial_index_enabled)
 	spatialite_gc = 1;
+    if (f_table_name && f_geometry_column && geometry_type && coord_dimension
+	&& gc_srid && spatial_index_enabled)
+	spatialite_gc = 3;
 
 /* checking the SPATIAL_REF_SYS table */
     strcpy (sql, "PRAGMA table_info(spatial_ref_sys)");
@@ -1607,6 +1617,7 @@ main (int argc, char *argv[])
     struct gml_params params;
     int ret;
     char *err_msg = NULL;
+    void *cache;
 
     params.db_handle = NULL;
     params.stmt = NULL;
@@ -1742,7 +1753,8 @@ main (int argc, char *argv[])
       }
 
 /* opening the DB */
-    open_db (db_path, &handle);
+    cache = spatialite_alloc_connection ();
+    open_db (db_path, &handle, cache);
     if (!handle)
 	return -1;
     params.db_handle = handle;
@@ -1781,6 +1793,9 @@ main (int argc, char *argv[])
 	  sqlite3_close (handle);
 	  handle = mem_db_handle;
 	  printf ("\nusing IN-MEMORY database\n");
+	  spatialite_cleanup_ex (cache);
+	  cache = spatialite_alloc_connection ();
+	  spatialite_init_ex (handle, cache, 0);
       }
 
 /* XML parsing */
@@ -1925,5 +1940,6 @@ main (int argc, char *argv[])
       }
 
     sqlite3_close (handle);
+    spatialite_cleanup_ex (cache);
     return 0;
 }
