@@ -34,7 +34,11 @@
 #include <string.h>
 #include <float.h>
 
+#if defined(_WIN32) && !defined(__MINGW32__)
+#include "config-msvc.h"
+#else
 #include "config.h"
+#endif
 
 #ifdef SPATIALITE_AMALGAMATION
 #include <spatialite/sqlite3.h>
@@ -1064,7 +1068,7 @@ spatialite_autocreate (sqlite3 * db)
 	return;
 
 /* all right, it's empty: proceding to initialize */
-    strcpy (sql, "SELECT InitSpatialMetadata()");
+    strcpy (sql, "SELECT InitSpatialMetadata(1)");
     ret = sqlite3_exec (db, sql, NULL, NULL, &err_msg);
     if (ret != SQLITE_OK)
       {
@@ -1146,8 +1150,8 @@ validate (char *path, char *table, char *from_column, char *to_column,
     double a_star_length;
     double a_star_coeff;
     double min_a_star_coeff = DBL_MAX;
-/* initializing SpatiaLite */
-    spatialite_init (0);
+    void *cache;
+
 /* showing the SQLite version */
     fprintf (stderr, "SQLite version: %s\n", sqlite3_libversion ());
 /* showing the SpatiaLite version */
@@ -1163,6 +1167,8 @@ validate (char *path, char *table, char *from_column, char *to_column,
 	  sqlite3_close (handle);
 	  return;
       }
+    cache = spatialite_alloc_connection ();
+    spatialite_init_ex (handle, cache, 0);
     spatialite_autocreate (handle);
 
     fprintf (stderr, "Step   I - checking for table and columns existence\n");
@@ -1212,7 +1218,7 @@ validate (char *path, char *table, char *from_column, char *to_column,
 	("==================================================================\n\n");
 /* checking for table existence */
     sprintf (sql,
-	     "SELECT \"tbl_name\" FROM \"sqlite_master\" WHERE \"tbl_name\" LIKE '%s' and \"type\" = 'table'",
+	     "SELECT \"tbl_name\" FROM \"sqlite_master\" WHERE Upper(\"tbl_name\") = Upper('%s') and \"type\" = 'table'",
 	     table);
     ret =
 	sqlite3_get_table (handle, sql, &results, &n_rows, &n_columns,
@@ -1820,6 +1826,7 @@ validate (char *path, char *table, char *from_column, char *to_column,
     if (ret != SQLITE_OK)
 	fprintf (stderr, "sqlite3_close() error: %s\n",
 		 sqlite3_errmsg (handle));
+    spatialite_cleanup_ex (cache);
     graph_free (p_graph);
 }
 
