@@ -33,7 +33,11 @@
 #include <stdio.h>
 #include <string.h>
 
+#if defined(_WIN32) && !defined(__MINGW32__)
+#include "config-msvc.h"
+#else
 #include "config.h"
+#endif
 
 #ifdef SPATIALITE_AMALGAMATION
 #include <spatialite/sqlite3.h>
@@ -1146,7 +1150,7 @@ parse_wkt_mask (const char *wkt_path, void **mask, int *mask_len)
 }
 
 static void
-open_db (const char *path, sqlite3 ** handle, int cache_size)
+open_db (const char *path, sqlite3 ** handle, int cache_size, void *cache)
 {
 /* opening the DB */
     sqlite3 *db_handle;
@@ -1164,6 +1168,7 @@ open_db (const char *path, sqlite3 ** handle, int cache_size)
     int coord_dimension = 0;
     int gc_srid = 0;
     int type = 0;
+    int geometry_type = 0;
     int spatial_index_enabled = 0;
     int node_id = 0;
     int version = 0;
@@ -1187,7 +1192,6 @@ open_db (const char *path, sqlite3 ** handle, int cache_size)
     int columns;
 
     *handle = NULL;
-    spatialite_init (0);
     printf ("SQLite version: %s\n", sqlite3_libversion ());
     printf ("SpatiaLite version: %s\n\n", spatialite_version ());
 
@@ -1199,6 +1203,7 @@ open_db (const char *path, sqlite3 ** handle, int cache_size)
 	  sqlite3_close (db_handle);
 	  return;
       }
+    spatialite_init_ex (db_handle, cache, 0);
     if (cache_size > 0)
       {
 	  /* setting the CACHE-SIZE */
@@ -1228,6 +1233,8 @@ open_db (const char *path, sqlite3 ** handle, int cache_size)
 		    gc_srid = 1;
 		if (strcasecmp (name, "type") == 0)
 		    type = 1;
+		if (strcasecmp (name, "geometry_type") == 0)
+		    geometry_type = 1;
 		if (strcasecmp (name, "spatial_index_enabled") == 0)
 		    spatial_index_enabled = 1;
 	    }
@@ -1236,6 +1243,9 @@ open_db (const char *path, sqlite3 ** handle, int cache_size)
     if (f_table_name && f_geometry_column && type && coord_dimension
 	&& gc_srid && spatial_index_enabled)
 	spatialite_gc = 1;
+    if (f_table_name && f_geometry_column && geometry_type && coord_dimension
+	&& gc_srid && spatial_index_enabled)
+	spatialite_gc = 3;
 
 /* checking the SPATIAL_REF_SYS table */
     strcpy (sql, "PRAGMA table_info(spatial_ref_sys)");
@@ -1596,6 +1606,7 @@ main (int argc, char *argv[])
     FILE *out = NULL;
     char *sql_err = NULL;
     int ret;
+    void *cache;
 
     for (i = 1; i < argc; i++)
       {
@@ -1730,7 +1741,8 @@ main (int argc, char *argv[])
 /* opening the DB */
     if (in_memory)
 	cache_size = 0;
-    open_db (db_path, &handle, cache_size);
+    cache = spatialite_alloc_connection ();
+    open_db (db_path, &handle, cache_size, cache);
     if (!handle)
 	return -1;
     if (in_memory)
@@ -1767,6 +1779,9 @@ main (int argc, char *argv[])
 	  sqlite3_close (handle);
 	  handle = mem_db_handle;
 	  printf ("\nusing IN-MEMORY database\n");
+	  spatialite_cleanup_ex (cache);
+	  cache = spatialite_alloc_connection ();
+	  spatialite_init_ex (handle, cache, 0);
       }
 
     out = fopen (osm_path, "wb");
@@ -1846,6 +1861,7 @@ main (int argc, char *argv[])
   stop:
     free (mask);
     sqlite3_close (handle);
+    spatialite_cleanup_ex (cache);
     if (out != NULL)
 	fclose (out);
     return 0;
