@@ -34,7 +34,11 @@
 #include <string.h>
 #include <float.h>
 
+#if defined(_WIN32) && !defined(__MINGW32__)
+#include "config-msvc.h"
+#else
 #include "config.h"
+#endif
 
 #ifdef SPATIALITE_AMALGAMATION
 #include <spatialite/sqlite3.h>
@@ -2010,7 +2014,7 @@ spatialite_autocreate (sqlite3 * db)
 	return;
 
 /* all right, it's empty: proceding to initialize */
-    strcpy (sql, "SELECT InitSpatialMetadata()");
+    strcpy (sql, "SELECT InitSpatialMetadata(1)");
     ret = sqlite3_exec (db, sql, NULL, NULL, &err_msg);
     if (ret != SQLITE_OK)
       {
@@ -2021,7 +2025,7 @@ spatialite_autocreate (sqlite3 * db)
 }
 
 static void
-open_db (const char *path, sqlite3 ** handle, int cache_size)
+open_db (const char *path, sqlite3 ** handle, int cache_size, void *cache)
 {
 /* opening the DB */
     sqlite3 *db_handle;
@@ -2040,6 +2044,7 @@ open_db (const char *path, sqlite3 ** handle, int cache_size)
     int coord_dimension = 0;
     int gc_srid = 0;
     int type = 0;
+    int geometry_type = 0;
     int spatial_index_enabled = 0;
     const char *name;
     int i;
@@ -2048,7 +2053,6 @@ open_db (const char *path, sqlite3 ** handle, int cache_size)
     int columns;
 
     *handle = NULL;
-    spatialite_init (0);
     printf ("SQLite version: %s\n", sqlite3_libversion ());
     printf ("SpatiaLite version: %s\n\n", spatialite_version ());
 
@@ -2062,6 +2066,7 @@ open_db (const char *path, sqlite3 ** handle, int cache_size)
 	  sqlite3_close (db_handle);
 	  return;
       }
+    spatialite_init_ex (db_handle, cache, 0);
     spatialite_autocreate (db_handle);
     if (cache_size > 0)
       {
@@ -2092,6 +2097,8 @@ open_db (const char *path, sqlite3 ** handle, int cache_size)
 		    gc_srid = 1;
 		if (strcasecmp (name, "type") == 0)
 		    type = 1;
+		if (strcasecmp (name, "geometry_type") == 0)
+		    geometry_type = 1;
 		if (strcasecmp (name, "spatial_index_enabled") == 0)
 		    spatial_index_enabled = 1;
 	    }
@@ -2100,6 +2107,9 @@ open_db (const char *path, sqlite3 ** handle, int cache_size)
     if (f_table_name && f_geometry_column && type && coord_dimension
 	&& gc_srid && spatial_index_enabled)
 	spatialite_gc = 1;
+    if (f_table_name && f_geometry_column && geometry_type && coord_dimension
+	&& gc_srid && spatial_index_enabled)
+	spatialite_gc = 3;
 
 /* checking the SPATIAL_REF_SYS table */
     strcpy (sql, "PRAGMA table_info(spatial_ref_sys)");
@@ -2568,6 +2578,7 @@ main (int argc, char *argv[])
     int error = 0;
     struct aux_params params;
     const void *osm_handle;
+    void *cache;
 
 /* initializing the aux-struct */
     params.db_handle = NULL;
@@ -2698,7 +2709,8 @@ main (int argc, char *argv[])
 /* opening the DB */
     if (in_memory)
 	cache_size = 0;
-    open_db (db_path, &handle, cache_size);
+    cache = spatialite_alloc_connection ();
+    open_db (db_path, &handle, cache_size, cache);
     if (!handle)
 	return -1;
     if (in_memory)
@@ -2736,6 +2748,9 @@ main (int argc, char *argv[])
 	  sqlite3_close (handle);
 	  handle = mem_db_handle;
 	  printf ("\nusing IN-MEMORY database\n");
+	  spatialite_cleanup_ex (cache);
+	  cache = spatialite_alloc_connection ();
+	  spatialite_init_ex (handle, cache, 0);
       }
     params.db_handle = handle;
 
@@ -2816,5 +2831,6 @@ main (int argc, char *argv[])
 /* VACUUMing */
     db_vacuum (handle);
     sqlite3_close (handle);
+    spatialite_cleanup_ex (cache);
     return 0;
 }
