@@ -33,7 +33,11 @@
 #include <stdio.h>
 #include <string.h>
 
+#if defined(_WIN32) && !defined(__MINGW32__)
+#include "config-msvc.h"
+#else
 #include "config.h"
+#endif
 
 #ifdef SPATIALITE_AMALGAMATION
 #include <spatialite/sqlite3.h>
@@ -1500,7 +1504,7 @@ spatialite_autocreate (sqlite3 * db)
     if (count > 0)
 	return;
 /* all right, it's empty: proceding to initialize */
-    strcpy (sql, "SELECT InitSpatialMetadata()");
+    strcpy (sql, "SELECT InitSpatialMetadata(1)");
     ret = sqlite3_exec (db, sql, NULL, NULL, &err_msg);
     if (ret != SQLITE_OK)
       {
@@ -1511,7 +1515,8 @@ spatialite_autocreate (sqlite3 * db)
 }
 
 static sqlite3 *
-open_db (const char *path, const char *table, int double_arcs, int cache_size)
+open_db (const char *path, const char *table, int double_arcs, int cache_size,
+	 void *cache)
 {
 /* opening the DB */
     sqlite3 *handle;
@@ -1530,13 +1535,14 @@ open_db (const char *path, const char *table, int double_arcs, int cache_size)
     int coord_dimension = 0;
     int gc_srid = 0;
     int type = 0;
+    int geometry_type = 0;
     int spatial_index_enabled = 0;
     const char *name;
     int i;
     char **results;
     int rows;
     int columns;
-    spatialite_init (0);
+
     printf ("SQLite version: %s\n", sqlite3_libversion ());
     printf ("SpatiaLite version: %s\n\n", spatialite_version ());
     ret =
@@ -1549,6 +1555,7 @@ open_db (const char *path, const char *table, int double_arcs, int cache_size)
 	  sqlite3_close (handle);
 	  return NULL;
       }
+    spatialite_init_ex (handle, cache, 0);
     spatialite_autocreate (handle);
     if (cache_size > 0)
       {
@@ -1578,6 +1585,8 @@ open_db (const char *path, const char *table, int double_arcs, int cache_size)
 		    gc_srid = 1;
 		if (strcasecmp (name, "type") == 0)
 		    type = 1;
+		if (strcasecmp (name, "geometry_type") == 0)
+		    geometry_type = 1;
 		if (strcasecmp (name, "spatial_index_enabled") == 0)
 		    spatial_index_enabled = 1;
 	    }
@@ -1586,6 +1595,10 @@ open_db (const char *path, const char *table, int double_arcs, int cache_size)
     if (f_table_name && f_geometry_column && type && coord_dimension
 	&& gc_srid && spatial_index_enabled)
 	spatialite_gc = 1;
+    if (f_table_name && f_geometry_column && geometry_type && coord_dimension
+	&& gc_srid && spatial_index_enabled)
+	spatialite_gc = 3;
+
 /* checking the SPATIAL_REF_SYS table */
     strcpy (sql, "PRAGMA table_info(spatial_ref_sys)");
     ret = sqlite3_get_table (handle, sql, &results, &rows, &columns, NULL);
@@ -2288,6 +2301,8 @@ main (int argc, char *argv[])
     sqlite3 *handle;
     struct aux_params params;
     const void *osm_handle;
+    void *cache;
+
 /* initializing the aux-struct */
     params.db_handle = NULL;
     params.ins_tmp_nodes_stmt = NULL;
@@ -2518,7 +2533,8 @@ main (int argc, char *argv[])
 /* opening the DB */
     if (in_memory)
 	cache_size = 0;
-    handle = open_db (db_path, table, double_arcs, cache_size);
+    cache = spatialite_alloc_connection ();
+    handle = open_db (db_path, table, double_arcs, cache_size, cache);
     if (!handle)
       {
 	  free_params (&params);
@@ -2561,6 +2577,9 @@ main (int argc, char *argv[])
 	  sqlite3_close (handle);
 	  handle = mem_handle;
 	  printf ("\nusing IN-MEMORY database\n");
+	  spatialite_cleanup_ex (cache);
+	  cache = spatialite_alloc_connection ();
+	  spatialite_init_ex (handle, cache, 0);
       }
     params.db_handle = handle;
     params.table = table;
@@ -2726,6 +2745,7 @@ main (int argc, char *argv[])
 /* VACUUMing */
     db_vacuum (handle);
     sqlite3_close (handle);
+    spatialite_cleanup_ex (cache);
     free_params (&params);
     return 0;
 }
