@@ -34,7 +34,11 @@
 #include <string.h>
 #include <errno.h>
 
+#if defined(_WIN32) && !defined(__MINGW32__)
+#include "config-msvc.h"
+#else
 #include "config.h"
+#endif
 
 #ifdef SPATIALITE_AMALGAMATION
 #include <spatialite/sqlite3.h>
@@ -93,7 +97,7 @@ spatialite_autocreate (sqlite3 * db)
 	return;
 
 /* all right, it's empty: proceding to initialize */
-    strcpy (sql, "SELECT InitSpatialMetadata()");
+    strcpy (sql, "SELECT InitSpatialMetadata(1)");
     ret = sqlite3_exec (db, sql, NULL, NULL, &err_msg);
     if (ret != SQLITE_OK)
       {
@@ -110,8 +114,8 @@ do_import_dbf (char *db_path, char *dbf_path, char *table, char *charset)
     int ret;
     int rows;
     sqlite3 *handle;
-/* initializing SpatiaLite */
-    spatialite_init (0);
+    void *cache;
+
 /* showing the SQLite version */
     fprintf (stderr, "SQLite version: %s\n", sqlite3_libversion ());
 /* showing the SpatiaLite version */
@@ -127,6 +131,8 @@ do_import_dbf (char *db_path, char *dbf_path, char *table, char *charset)
 	  sqlite3_close (handle);
 	  return;
       }
+    cache = spatialite_alloc_connection ();
+    spatialite_init_ex (handle, cache, 0);
     spatialite_autocreate (handle);
     if (load_dbf (handle, dbf_path, table, charset, 0, &rows, NULL))
 	fprintf (stderr, "Inserted %d rows into '%s' from '%s'\n", rows, table,
@@ -138,6 +144,7 @@ do_import_dbf (char *db_path, char *dbf_path, char *table, char *charset)
     if (ret != SQLITE_OK)
 	fprintf (stderr, "sqlite3_close() error: %s\n",
 		 sqlite3_errmsg (handle));
+    spatialite_cleanup_ex (cache);
 }
 
 static void
@@ -148,8 +155,8 @@ do_import_shp (char *db_path, char *shp_path, char *table, char *charset,
     int ret;
     int rows;
     sqlite3 *handle;
-/* initializing SpatiaLite */
-    spatialite_init (0);
+    void *cache;
+
 /* showing the SQLite version */
     fprintf (stderr, "SQLite version: %s\n", sqlite3_libversion ());
 /* showing the SpatiaLite version */
@@ -165,6 +172,8 @@ do_import_shp (char *db_path, char *shp_path, char *table, char *charset,
 	  sqlite3_close (handle);
 	  return;
       }
+    cache = spatialite_alloc_connection ();
+    spatialite_init_ex (handle, cache, 0);
     spatialite_autocreate (handle);
     if (load_shapefile
 	(handle, shp_path, table, charset, srid, column, coerce2d, compressed,
@@ -178,6 +187,7 @@ do_import_shp (char *db_path, char *shp_path, char *table, char *charset,
     if (ret != SQLITE_OK)
 	fprintf (stderr, "sqlite3_close() error: %s\n",
 		 sqlite3_errmsg (handle));
+    spatialite_cleanup_ex (cache);
 }
 
 static void
@@ -188,8 +198,8 @@ do_export (char *db_path, char *shp_path, char *table, char *column,
     int ret;
     int rows;
     sqlite3 *handle;
-/* initializing SpatiaLite */
-    spatialite_init (0);
+    void *cache;
+
 /* showing the SQLite version */
     fprintf (stderr, "SQLite version: %s\n", sqlite3_libversion ());
 /* showing the SpatiaLite version */
@@ -203,6 +213,8 @@ do_export (char *db_path, char *shp_path, char *table, char *column,
 	  sqlite3_close (handle);
 	  return;
       }
+    cache = spatialite_alloc_connection ();
+    spatialite_init_ex (handle, cache, 0);
     if (dump_shapefile
 	(handle, table, column, shp_path, charset, type, 0, &rows, NULL))
 	fprintf (stderr, "Exported %d rows into '%s.shp' from '%s'\n", rows,
@@ -214,6 +226,7 @@ do_export (char *db_path, char *shp_path, char *table, char *column,
     if (ret != SQLITE_OK)
 	fprintf (stderr, "sqlite3_close() error: %s\n",
 		 sqlite3_errmsg (handle));
+    spatialite_cleanup_ex (cache);
 }
 
 static void
